@@ -79,7 +79,7 @@ parse_get_snaps_response (SnapdRequest *request, SoupMessage *message, SnapdMain
 {
     SnapdGetSnaps *self = SNAPD_GET_SNAPS (request);
 
-    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, NULL, error);
     if (response == NULL)
         return FALSE;
     g_autoptr(JsonArray) result = _snapd_json_get_sync_result_a (response, error);
