@@ -159,8 +159,15 @@ _snapd_json_get_date_time (JsonObject *object, const gchar *name)
         timezone_start = tokens[1];
         while (*timezone_start != '\0' && !is_timezone_prefix (*timezone_start))
             timezone_start++;
-        if (*timezone_start != '\0')
+        if (*timezone_start != '\0') {
+#ifdef GLIB_VERSION_2_68
+            timezone = g_time_zone_new_identifier (timezone_start);
+            if (timezone == NULL)
+                timezone = g_time_zone_new_utc ();
+#else
             timezone = g_time_zone_new (timezone_start);
+#endif
+        }
 
         /* Strip off timezone */
         *timezone_start = '\0';
@@ -176,13 +183,19 @@ _snapd_json_get_date_time (JsonObject *object, const gchar *name)
 }
 
 static void
-parse_error_response (JsonObject *root, GError **error)
+parse_error_response (JsonObject *root, JsonNode **error_value, GError **error)
 {
     JsonObject *result = _snapd_json_get_object (root, "result");
     gint64 status_code = _snapd_json_get_int (root, "status-code", 0);
     const gchar *kind = result != NULL ? _snapd_json_get_string (result, "kind", NULL) : NULL;
     const gchar *message = result != NULL ? _snapd_json_get_string (result, "message", NULL) : NULL;
 
+    if (error_value != NULL) {
+        *error_value = result != NULL ? json_object_get_member (result, "value") : NULL;
+        if (*error_value != NULL)
+            json_node_ref (*error_value);
+    }
+
     if (g_strcmp0 (kind, "login-required") == 0)
         g_set_error_literal (error,
                              SNAPD_ERROR,
@@ -308,6 +321,11 @@ parse_error_response (JsonObject *root, GError **error)
                              SNAPD_ERROR,
                              SNAPD_ERROR_OPTION_NOT_FOUND,
                              message);
+    else if (g_strcmp0 (kind, "unsuccessful") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_UNSUCCESSFUL,
+                             message);
     else {
         switch (status_code) {
         case SOUP_STATUS_BAD_REQUEST:
@@ -349,7 +367,7 @@ parse_error_response (JsonObject *root, GError **error)
 }
 
 JsonObject *
-_snapd_json_parse_response (SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
+_snapd_json_parse_response (SoupMessage *message, SnapdMaintenance **maintenance, JsonNode **error_value, GError **error)
 {
     const gchar *content_type = soup_message_headers_get_content_type (message->response_headers, NULL);
     if (content_type == NULL) {
@@ -398,7 +416,7 @@ _snapd_json_parse_response (SoupMessage *message, SnapdMaintenance **maintenance
     }
 
     if (strcmp (json_node_get_string (type_node), "error") == 0) {
-        parse_error_response (root, error);
+        parse_error_response (root, error_value, error);
         return NULL;
     }
 
@@ -849,6 +867,7 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
                          "screenshots", screenshots_array,
                          "snap-type", snap_type,
                          "status", snap_status,
+                         "store-url", _snapd_json_get_string (object, "store-url", NULL),
                          "summary", _snapd_json_get_string (object, "summary", NULL),
                          "title", _snapd_json_get_string (object, "title", NULL),
                          "tracking-channel", _snapd_json_get_string (object, "tracking-channel", NULL),
