@@ -207,6 +207,23 @@ typedef enum
     SNAPD_GET_INTERFACES_FLAGS_ONLY_CONNECTED = 1 << 3,
 } SnapdGetInterfacesFlags;
 
+/**
+ * SnapdThemeStatus:
+ * @SNAPD_THEME_STATUS_INSTALLED: the theme is installed.
+ * @SNAPD_THEME_STATUS_AVAILABLE: the theme is not installed but a package is available.
+ * @SNAPD_THEME_STATUS_UNAVAILABLE: the theme is not available.
+ *
+ * The status of a snap-packaged desktop theme.
+ *
+ * Since: 1.60
+ */
+typedef enum
+{
+    SNAPD_THEME_STATUS_INSTALLED = 1,
+    SNAPD_THEME_STATUS_AVAILABLE,
+    SNAPD_THEME_STATUS_UNAVAILABLE,
+} SnapdThemeStatus;
+
 /**
  * SnapdProgressCallback:
  * @client: a #SnapdClient
@@ -1091,20 +1108,40 @@ gboolean                snapd_client_reset_aliases_finish          (SnapdClient
 gboolean                snapd_client_run_snapctl_sync              (SnapdClient          *client,
                                                                     const gchar          *context_id,
                                                                     GStrv                 args,
-                                                                    GStrv                 stdout_output,
-                                                                    GStrv                 stderr_output,
+                                                                    gchar               **stdout_output,
+                                                                    gchar               **stderr_output,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_run_snapctl2_sync);
 void                    snapd_client_run_snapctl_async             (SnapdClient          *client,
                                                                     const gchar          *context_id,
                                                                     GStrv                 args,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED_FOR(snapd_client_run_snapctl2_async);
 gboolean                snapd_client_run_snapctl_finish            (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     gchar               **stdout_output,
                                                                     gchar               **stderr_output,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_run_snapctl2_finish);
+gboolean                snapd_client_run_snapctl2_sync             (SnapdClient          *client,
+                                                                    const gchar          *context_id,
+                                                                    GStrv                 args,
+                                                                    gchar               **stdout_output,
+                                                                    gchar               **stderr_output,
+                                                                    int                  *exit_code,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_run_snapctl2_async            (SnapdClient          *client,
+                                                                    const gchar          *context_id,
+                                                                    GStrv                 args,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_run_snapctl2_finish           (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    gchar               **stdout_output,
+                                                                    gchar               **stderr_output,
+                                                                    int                  *exit_code,
                                                                     GError              **error);
 
 GBytes                 *snapd_client_download_sync                 (SnapdClient          *client,
@@ -1124,6 +1161,50 @@ GBytes                 *snapd_client_download_finish               (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+gboolean                snapd_client_check_themes_sync             (SnapdClient          *client,
+                                                                    GStrv                 gtk_theme_names,
+                                                                    GStrv                 icon_theme_names,
+                                                                    GStrv                 sound_theme_names,
+                                                                    GHashTable          **gtk_theme_status,
+                                                                    GHashTable          **icon_theme_status,
+                                                                    GHashTable          **sound_theme_status,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_check_themes_async            (SnapdClient          *client,
+                                                                    GStrv                 gtk_theme_names,
+                                                                    GStrv                 icon_theme_names,
+                                                                    GStrv                 sound_theme_names,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_check_themes_finish           (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GHashTable          **gtk_theme_status,
+                                                                    GHashTable          **icon_theme_status,
+                                                                    GHashTable          **sound_theme_status,
+                                                                    GError              **error);
+
+gboolean                snapd_client_install_themes_sync           (SnapdClient          *client,
+                                                                    GStrv                 gtk_theme_names,
+                                                                    GStrv                 icon_theme_names,
+                                                                    GStrv                 sound_theme_names,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_install_themes_async          (SnapdClient          *client,
+                                                                    GStrv                 gtk_theme_names,
+                                                                    GStrv                 icon_theme_names,
+                                                                    GStrv                 sound_theme_names,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_install_themes_finish         (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 G_END_DECLS
 
 #endif /* __SNAPD_CLIENT_H__ */
