@@ -11,6 +11,7 @@
 #define SNAPD_CLIENT_H
 
 #include <QtCore/QObject>
+#include <QtCore/QScopedPointer>
 #include <QIODevice>
 #include <QLocalSocket>
 #include <Snapd/Alias>
@@ -39,7 +40,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdConnectRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdConnectRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdConnectRequest)
 };
 
@@ -60,7 +61,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdLoginRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdLoginRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdLoginRequest)
 };
 
@@ -77,7 +78,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdLogoutRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdLogoutRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdLogoutRequest)
 };
 
@@ -97,7 +98,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetChangesRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetChangesRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetChangesRequest)
 };
 
@@ -115,7 +116,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetChangeRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetChangeRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetChangeRequest)
 };
 
@@ -133,7 +134,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdAbortChangeRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdAbortChangeRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdAbortChangeRequest)
 };
 
@@ -152,7 +153,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetSystemInformationRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetSystemInformationRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetSystemInformationRequest)
 };
 
@@ -172,7 +173,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdListRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdListRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdListRequest)
 };
 
@@ -192,7 +193,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetSnapsRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetSnapsRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetSnapsRequest)
 };
 
@@ -210,7 +211,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdListOneRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdListOneRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdListOneRequest)
 };
 
@@ -228,7 +229,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetSnapRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetSnapRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetSnapRequest)
 };
 
@@ -246,7 +247,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetSnapConfRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetSnapConfRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetSnapConfRequest)
 };
 
@@ -263,7 +264,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdSetSnapConfRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdSetSnapConfRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdSetSnapConfRequest)
 };
 
@@ -284,7 +285,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetAppsRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetAppsRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetAppsRequest)
 };
 
@@ -302,7 +303,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetIconRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetIconRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetIconRequest)
 };
 
@@ -321,7 +322,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetAssertionsRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetAssertionsRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetAssertionsRequest)
 };
 
@@ -338,7 +339,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdAddAssertionsRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdAddAssertionsRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdAddAssertionsRequest)
 };
 
@@ -365,7 +366,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetConnectionsRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetConnectionsRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetConnectionsRequest)
 };
 
@@ -388,7 +389,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetInterfacesRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetInterfacesRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetInterfacesRequest)
 };
 
@@ -408,7 +409,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetInterfaces2RequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetInterfaces2RequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetInterfaces2Request)
 };
 
@@ -425,7 +426,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdConnectInterfaceRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdConnectInterfaceRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdConnectInterfaceRequest)
 };
 
@@ -442,7 +443,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdDisconnectInterfaceRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdDisconnectInterfaceRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdDisconnectInterfaceRequest)
 };
 
@@ -464,7 +465,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdFindRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdFindRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdFindRequest)
 };
 
@@ -484,7 +485,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdFindRefreshableRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdFindRefreshableRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdFindRefreshableRequest)
 };
 
@@ -501,7 +502,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdInstallRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdInstallRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdInstallRequest)
 };
 
@@ -512,12 +513,13 @@ class Q_DECL_EXPORT QSnapdTryRequest : public QSnapdRequest
 
 public:
     explicit QSnapdTryRequest (const QString& path, void *snapd_client, QObject *parent = 0);
+    ~QSnapdTryRequest ();
     virtual void runSync ();
     virtual void runAsync ();
     void handleResult (void *, void *);
 
 private:
-    QSnapdTryRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdTryRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdTryRequest)
 };
 
@@ -534,7 +536,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdRefreshRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdRefreshRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdRefreshRequest)
 };
 
@@ -553,7 +555,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdRefreshAllRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdRefreshAllRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdRefreshAllRequest)
 };
 
@@ -570,7 +572,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdRemoveRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdRemoveRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdRemoveRequest)
 };
 
@@ -587,7 +589,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdEnableRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdEnableRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdEnableRequest)
 };
 
@@ -604,7 +606,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdDisableRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdDisableRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdDisableRequest)
 };
 
@@ -621,7 +623,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdSwitchChannelRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdSwitchChannelRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdSwitchChannelRequest)
 };
 
@@ -640,7 +642,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdCheckBuyRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdCheckBuyRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdCheckBuyRequest)
 };
 
@@ -657,7 +659,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdBuyRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdBuyRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdBuyRequest)
 };
 
@@ -675,7 +677,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdCreateUserRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdCreateUserRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdCreateUserRequest)
 };
 
@@ -695,7 +697,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdCreateUsersRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdCreateUsersRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdCreateUsersRequest)
 };
 
@@ -715,7 +717,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetUsersRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetUsersRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetUsersRequest)
 };
 
@@ -733,7 +735,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetSectionsRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetSectionsRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetSectionsRequest)
 };
 
@@ -753,7 +755,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdGetAliasesRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdGetAliasesRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdGetAliasesRequest)
 };
 
@@ -770,7 +772,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdAliasRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdAliasRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdAliasRequest)
 };
 
@@ -787,7 +789,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdUnaliasRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdUnaliasRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdUnaliasRequest)
 };
 
@@ -804,7 +806,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdPreferRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdPreferRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdPreferRequest)
 };
 
@@ -821,7 +823,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdEnableAliasesRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdEnableAliasesRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdEnableAliasesRequest)
 };
 
@@ -838,7 +840,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdDisableAliasesRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdDisableAliasesRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdDisableAliasesRequest)
 };
 
@@ -855,7 +857,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdResetAliasesRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdResetAliasesRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdResetAliasesRequest)
 };
 
@@ -871,10 +873,11 @@ public:
     virtual void runAsync ();
     Q_INVOKABLE QString stdout () const;
     Q_INVOKABLE QString stderr () const;
+    Q_INVOKABLE int exitCode () const;
     void handleResult (void *, void *);
 
 private:
-    QSnapdRunSnapCtlRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdRunSnapCtlRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdRunSnapCtlRequest)
 };
 
@@ -892,7 +895,7 @@ public:
     void handleResult (void *, void *);
 
 private:
-    QSnapdDownloadRequestPrivate *d_ptr;
+    QScopedPointer<QSnapdDownloadRequestPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdDownloadRequest)
 };
 
@@ -1066,7 +1069,7 @@ public:
     Q_INVOKABLE QSnapdDownloadRequest *download (const QString &name, const QString &channel, const QString &revision);
 
 private:
-    QSnapdClientPrivate *d_ptr;
+    QScopedPointer<QSnapdClientPrivate> d_ptr;
     Q_DECLARE_PRIVATE(QSnapdClient)
 };
 
