@@ -11,6 +11,8 @@
 #define SNAPD_SYSTEM_INFORMATION_H
 
 #include <QtCore/QObject>
+#include <QtCore/QDateTime>
+#include <QHash>
 #include <Snapd/WrappedObject>
 #include <Snapd/Enums>
 
@@ -19,6 +21,7 @@ class Q_DECL_EXPORT QSnapdSystemInformation : public QSnapdWrappedObject
     Q_OBJECT
 
     Q_PROPERTY(QString binariesDirectory READ binariesDirectory)
+    Q_PROPERTY(QString buildId READ buildId)
     Q_PROPERTY(QSnapdEnums::SystemConfinement confinement READ confinement)
     Q_PROPERTY(QString kernelVersion READ kernelVersion)
     Q_PROPERTY(bool managed READ managed)
@@ -26,6 +29,12 @@ class Q_DECL_EXPORT QSnapdSystemInformation : public QSnapdWrappedObject
     Q_PROPERTY(bool onClassic READ onClassic)
     Q_PROPERTY(QString osId READ osId)
     Q_PROPERTY(QString osVersion READ osVersion)
+    Q_PROPERTY(QDateTime refreshHold READ refreshHold)
+    Q_PROPERTY(QDateTime refreshLast READ refreshLast)
+    Q_PROPERTY(QDateTime refreshNext READ refreshNext)
+    Q_PROPERTY(QString refreshSchedule READ refreshSchedule)
+    Q_PROPERTY(QString refreshTimer READ refreshTimer)
+    Q_PROPERTY(QHash<QString, QStringList> sandboxFeatures READ sandboxFeatures)
     Q_PROPERTY(QString series READ series)
     Q_PROPERTY(QString store READ store)
     Q_PROPERTY(QString version READ version)
@@ -34,6 +43,7 @@ public:
     explicit QSnapdSystemInformation (void *snapd_object, QObject* parent = 0);
 
     QString binariesDirectory () const;
+    QString buildId () const;
     QSnapdEnums::SystemConfinement confinement () const;
     QString kernelVersion () const;
     bool managed () const;
@@ -41,6 +51,12 @@ public:
     bool onClassic () const;
     QString osId () const;
     QString osVersion () const;
+    QDateTime refreshHold () const;
+    QDateTime refreshLast () const;
+    QDateTime refreshNext () const;
+    QString refreshSchedule () const;
+    QString refreshTimer () const;
+    QHash<QString, QStringList> sandboxFeatures () const;
     QString series () const;
     QString store () const;
     QString version () const;
