@@ -42,9 +42,7 @@ QSnapdRequest::QSnapdRequest (void *snapd_client, QObject *parent) :
     d_ptr (new QSnapdRequestPrivate (snapd_client)) {}
 
 QSnapdRequest::~QSnapdRequest ()
-{
-    delete d_ptr;
-}
+{}
 
 void* QSnapdRequest::getClient () const
 {
